Struct

GeglBufferIterator

Description

struct GeglBufferIterator {
  gint length;
  GeglBufferIteratorPriv* priv;
  None items;
}
No description available.
Structure members
length
No description available.
priv
No description available.
items
No description available.

Functions

gegl_buffer_iterator_empty_new

Create a new buffer iterator without adding any sub-iterators.

Instance methods

gegl_buffer_iterator_add

Adds an additional buffer sub-iterator into iterator that will be processed in sync with the first one (unless this is the first sub-iterator).

gegl_buffer_iterator_next

Do an iteration. If there is more data to process, a new set of linear chunks of memory becomes available in all items via GeglBufferIteratorItem.

gegl_buffer_iterator_stop

Cancels the current iteration and invalidates the GeglBufferIterator.